@@ -132,7 +132,7 @@ class CHGraph(object):
         if edge_con_list is not None and len(edge_con_list) > 0:
             edge_con_list_con = " and " + " and ".join(edge_con_list)
 
-        target_field_list_con = edge_info["src"] + "," + edge_info["dst"]
+        target_field_list_con = edge_info["rank"] + "," + edge_info["src"] + "," + edge_info["dst"]
         if target_field_list is None:
             target_field_list_con += "," + ",".join(edge_info["fields"])
         elif type(target_field_list) == list and len(target_field_list) > 0:
@@ -745,8 +745,13 @@ class CHGraph(object):
                         continue
                     edge_info = self.graph_cfg["edges"][edge_name_list[i]]
                     db_table = subgraph_name + "." + edge_info["table"]
-                    target_field_list_con = edge_info["src"] + "," + edge_info["dst"] + "," + ",".join(
-                        edge_info["fields"])
+                    schema_fields = edge_info.get("fields")
+                    if schema_fields:
+                        target_field_list_con = edge_info["rank"] + "," + edge_info["src"] + "," + \
+                                                edge_info["dst"] + "," + ",".join(schema_fields)
+                    else:
+                        target_field_list_con = edge_info["rank"] + "," + edge_info["src"] + "," + \
+                                                edge_info["dst"]
 
                     # TODO: list hurts performance and increases memory cost
                     col_list = [list(pd.to_datetime(single_res[i][col])) if str(
@@ -835,13 +840,15 @@ class CHGraph(object):
             col_list = [
                 list(pd.to_datetime(res[col])) if str(res[col].dtype) == "datetime64[ns]" else list(res[col].values) for
                 col in res.columns]
-            try:
-                prefix_sql = "insert into " + db_table + " (" + target_field_list_con + ") values"
-                logger.info("[update_subgraph_by_sql] sql: {}".format(prefix_sql))
 
-                self.client.execute(prefix_sql, col_list, columnar=True)
-            except Exception as exc:
-                raise ValueError("update subgraph failed. errMsg:{}".format(str(exc)))
+            if target_field_list_con:
+                try:
+                    prefix_sql = "insert into " + db_table + " (" + target_field_list_con + ") values"
+                    logger.info("[update_subgraph_by_sql] sql: {}".format(prefix_sql))
+
+                    self.client.execute(prefix_sql, col_list, columnar=True)
+                except Exception as exc:
+                    raise ValueError("update subgraph failed. errMsg:{}".format(str(exc)))
 
             return col_list, column_fileds
 
@@ -1083,7 +1090,8 @@ class CHGraph(object):
         sql = "select " + edge_info["src"] + "," + edge_info["dst"] + ",outdegree from (select " + edge_info[
             "src"] + ",count(*) as outdegree from " + db_table + " group by " + edge_info[
                   "src"] + ") as table_od join " + db_table + " using " + edge_info["src"] + qualifier
-        print(sql)
+
+        logger.info("[metric_pagerank] sql: {}".format(sql))
         res = self.client.query_dataframe(sql)
         return res.to_dict()
 
@@ -1093,19 +1101,25 @@ class CHGraph(object):
         table_property = propertys[vertex_name]
         db_table = table_property["db"] + "." + table_property["table"]
         target_field_list_con = table_property["id"]
-        if target_field_list is None or len(target_field_list) == 0:
-            target_field_list_con += "," + ",".join(table_property["fields"])
-        elif len(target_field_list) > 0:
+        if not target_field_list:
+            table_fields = table_property["fields"]
+            if table_fields:
+                target_field_list_con += "," + ",".join(table_fields)
+        else:
             target_field_list_con += "," + ",".join(target_field_list)
+
         vertex_con_list_con = " where " + table_property["id"] + " in " + tostr(vertex_id_list)
         if vertex_con_list is not None and len(vertex_con_list) > 0:
             vertex_con_list_con += " and " + " and ".join(vertex_con_list)
 
         num = self.client.execute("select count(1) from " + db_table + vertex_con_list_con)
         count = num[0][0]
-        if page is not None and page_size is not None:
+        if page and page_size:
             vertex_con_list_con = vertex_con_list_con + " limit " + str(page_size * (page - 1)) + "," + str(page_size)
+
         sql = "select DISTINCT " + target_field_list_con + " from " + db_table + vertex_con_list_con
+        logger.info("[vertex_match_property]  select sql: {}".format(sql))
+
         res = deal_query_result_with_paging(data_type, self.client, sql, page, page_size, count)
         return res
 
